JBossWS SVN: r3448 - trunk/build.
by jbossws-commits@lists.jboss.org
Author: heiko.braun(a)jboss.com
Date: 2007-06-05 11:02:52 -0400 (Tue, 05 Jun 2007)
New Revision: 3448
Modified:
trunk/build/version.properties
Log:
Added gnu-getopt to common binary dependencies
Modified: trunk/build/version.properties
===================================================================
--- trunk/build/version.properties 2007-06-05 15:02:13 UTC (rev 3447)
+++ trunk/build/version.properties 2007-06-05 15:02:52 UTC (rev 3448)
@@ -16,6 +16,7 @@
# Thirdparty library versions
apache-ant=1.6.5
dom4j=1.6.1
+gnu-getopt=1.0.10
jboss-common-core=2.0.2.GA
jboss-common-logging-log4j=2.0.2.GA
jboss-common-logging-spi=2.0.2.GA
18 years, 10 months
JBossWS SVN: r3447 - trunk/jbossws-core.
by jbossws-commits@lists.jboss.org
Author: heiko.braun(a)jboss.com
Date: 2007-06-05 11:02:13 -0400 (Tue, 05 Jun 2007)
New Revision: 3447
Modified:
trunk/jbossws-core/build.xml
Log:
Include scripts in jbossws-client.jar
Modified: trunk/jbossws-core/build.xml
===================================================================
--- trunk/jbossws-core/build.xml 2007-06-05 14:23:26 UTC (rev 3446)
+++ trunk/jbossws-core/build.xml 2007-06-05 15:02:13 UTC (rev 3447)
@@ -162,6 +162,8 @@
</fileset>
<fileset dir="${core.etc.dir}">
<include name="log4j.properties"/>
+ <include name="ws*.bat"/>
+ <include name="ws*.sh"/>
</fileset>
<metainf dir="${core.resources.dir}/jbossws-core.jar/META-INF"/>
<metainf dir="${core.resources.dir}/standard-config">
18 years, 10 months
JBossWS SVN: r3446 - branches/dlofthouse.
by jbossws-commits@lists.jboss.org
Author: darran.lofthouse(a)jboss.com
Date: 2007-06-05 10:23:26 -0400 (Tue, 05 Jun 2007)
New Revision: 3446
Removed:
branches/dlofthouse/JBWS-1133/
Log:
Won't Fix
18 years, 10 months
JBossWS SVN: r3445 - in trunk/build/hudson/hudson-home/jobs: AS-Tests-AS-4.2 and 18 other directories.
by jbossws-commits@lists.jboss.org
Author: thomas.diesler(a)jboss.com
Date: 2007-06-05 05:55:00 -0400 (Tue, 05 Jun 2007)
New Revision: 3445
Modified:
trunk/build/hudson/hudson-home/jobs/AS-Tests-AS-4.0/config.xml
trunk/build/hudson/hudson-home/jobs/AS-Tests-AS-4.2/config.xml
trunk/build/hudson/hudson-home/jobs/AS-Tests-AS-5.0/config.xml
trunk/build/hudson/hudson-home/jobs/Core-Tests-AS-4.0/config.xml
trunk/build/hudson/hudson-home/jobs/Core-Tests-AS-4.2/config.xml
trunk/build/hudson/hudson-home/jobs/Core-Tests-AS-5.0/config.xml
trunk/build/hudson/hudson-home/jobs/Distro-Native-AS-4.0/config.xml
trunk/build/hudson/hudson-home/jobs/Distro-Native-AS-4.2/config.xml
trunk/build/hudson/hudson-home/jobs/Distro-Native-AS-5.0/config.xml
trunk/build/hudson/hudson-home/jobs/Distro-SunRI-AS-4.2/config.xml
trunk/build/hudson/hudson-home/jobs/Distro-SunRI-AS-5.0/config.xml
trunk/build/hudson/hudson-home/jobs/Distro-XFire-AS-4.2/config.xml
trunk/build/hudson/hudson-home/jobs/Distro-XFire-AS-5.0/config.xml
trunk/build/hudson/hudson-home/jobs/Integration-Native-AS-4.0/config.xml
trunk/build/hudson/hudson-home/jobs/Integration-Native-AS-4.2/config.xml
trunk/build/hudson/hudson-home/jobs/Integration-Native-AS-5.0/config.xml
trunk/build/hudson/hudson-home/jobs/Integration-SunRI-AS-4.2/config.xml
trunk/build/hudson/hudson-home/jobs/Integration-SunRI-AS-5.0/config.xml
trunk/build/hudson/hudson-home/jobs/Integration-XFire-AS-4.2/config.xml
trunk/build/hudson/hudson-home/jobs/Integration-XFire-AS-5.0/config.xml
Log:
Use exit instead of return
Modified: trunk/build/hudson/hudson-home/jobs/AS-Tests-AS-4.0/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/AS-Tests-AS-4.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/AS-Tests-AS-4.0/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -42,7 +42,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/AS-Tests-AS-4.2/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/AS-Tests-AS-4.2/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/AS-Tests-AS-4.2/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/AS-Tests-AS-5.0/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/AS-Tests-AS-5.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/AS-Tests-AS-5.0/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Core-Tests-AS-4.0/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Core-Tests-AS-4.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Core-Tests-AS-4.0/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Core-Tests-AS-4.2/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Core-Tests-AS-4.2/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Core-Tests-AS-4.2/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Core-Tests-AS-5.0/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Core-Tests-AS-5.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Core-Tests-AS-5.0/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Distro-Native-AS-4.0/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Distro-Native-AS-4.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Distro-Native-AS-4.0/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -50,7 +50,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Distro-Native-AS-4.2/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Distro-Native-AS-4.2/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Distro-Native-AS-4.2/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -50,7 +50,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Distro-Native-AS-5.0/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Distro-Native-AS-5.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Distro-Native-AS-5.0/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -50,7 +50,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Distro-SunRI-AS-4.2/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Distro-SunRI-AS-4.2/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Distro-SunRI-AS-4.2/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -49,7 +49,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Distro-SunRI-AS-5.0/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Distro-SunRI-AS-5.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Distro-SunRI-AS-5.0/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -49,7 +49,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Distro-XFire-AS-4.2/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Distro-XFire-AS-4.2/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Distro-XFire-AS-4.2/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -49,7 +49,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Distro-XFire-AS-5.0/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Distro-XFire-AS-5.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Distro-XFire-AS-5.0/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -49,7 +49,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Integration-Native-AS-4.0/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Integration-Native-AS-4.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Integration-Native-AS-4.0/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Integration-Native-AS-4.2/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Integration-Native-AS-4.2/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Integration-Native-AS-4.2/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Integration-Native-AS-5.0/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Integration-Native-AS-5.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Integration-Native-AS-5.0/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Integration-SunRI-AS-4.2/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Integration-SunRI-AS-4.2/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Integration-SunRI-AS-4.2/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Integration-SunRI-AS-5.0/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Integration-SunRI-AS-5.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Integration-SunRI-AS-5.0/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Integration-XFire-AS-4.2/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Integration-XFire-AS-4.2/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Integration-XFire-AS-4.2/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: trunk/build/hudson/hudson-home/jobs/Integration-XFire-AS-5.0/config.xml
===================================================================
--- trunk/build/hudson/hudson-home/jobs/Integration-XFire-AS-5.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
+++ trunk/build/hudson/hudson-home/jobs/Integration-XFire-AS-5.0/config.xml 2007-06-05 09:55:00 UTC (rev 3445)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
18 years, 10 months
JBossWS SVN: r3444 - in branches/jbossws-2.0/build/hudson/hudson-home/jobs: AS-Tests-AS-4.2 and 10 other directories.
by jbossws-commits@lists.jboss.org
Author: thomas.diesler(a)jboss.com
Date: 2007-06-05 05:53:38 -0400 (Tue, 05 Jun 2007)
New Revision: 3444
Modified:
branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-4.0/config.xml
branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-4.2/config.xml
branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-5.0/config.xml
branches/jbossws-2.0/build/hudson/hudson-home/jobs/Core-Tests-AS-4.0/config.xml
branches/jbossws-2.0/build/hudson/hudson-home/jobs/Core-Tests-AS-4.2/config.xml
branches/jbossws-2.0/build/hudson/hudson-home/jobs/Core-Tests-AS-5.0/config.xml
branches/jbossws-2.0/build/hudson/hudson-home/jobs/Distro-Native-AS-4.0/config.xml
branches/jbossws-2.0/build/hudson/hudson-home/jobs/Distro-Native-AS-4.2/config.xml
branches/jbossws-2.0/build/hudson/hudson-home/jobs/Distro-Native-AS-5.0/config.xml
branches/jbossws-2.0/build/hudson/hudson-home/jobs/Integration-Native-AS-4.0/config.xml
branches/jbossws-2.0/build/hudson/hudson-home/jobs/Integration-Native-AS-4.2/config.xml
branches/jbossws-2.0/build/hudson/hudson-home/jobs/Integration-Native-AS-5.0/config.xml
Log:
Use exit instead of return
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-4.0/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-4.0/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-4.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
@@ -42,7 +42,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-4.2/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-4.2/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-4.2/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-5.0/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-5.0/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-5.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/Core-Tests-AS-4.0/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/Core-Tests-AS-4.0/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/Core-Tests-AS-4.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/Core-Tests-AS-4.2/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/Core-Tests-AS-4.2/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/Core-Tests-AS-4.2/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/Core-Tests-AS-5.0/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/Core-Tests-AS-5.0/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/Core-Tests-AS-5.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/Distro-Native-AS-4.0/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/Distro-Native-AS-4.0/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/Distro-Native-AS-4.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
@@ -50,7 +50,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/Distro-Native-AS-4.2/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/Distro-Native-AS-4.2/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/Distro-Native-AS-4.2/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
@@ -50,7 +50,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/Distro-Native-AS-5.0/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/Distro-Native-AS-5.0/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/Distro-Native-AS-5.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
@@ -50,7 +50,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/Integration-Native-AS-4.0/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/Integration-Native-AS-4.0/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/Integration-Native-AS-4.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/Integration-Native-AS-4.2/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/Integration-Native-AS-4.2/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/Integration-Native-AS-4.2/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/Integration-Native-AS-5.0/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/Integration-Native-AS-5.0/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/Integration-Native-AS-5.0/config.xml 2007-06-05 09:53:38 UTC (rev 3444)
@@ -41,7 +41,7 @@
$JBWSDIR/build/hudson/jboss/bin/http-spider.sh $JBOSS_BINDADDR:8080 $WORKSPACE
if [ -e $WORKSPACE/spider.failed ]; then
$JBWSDIR/build/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BINDADDR
- return 1
+ exit 1
fi
#
18 years, 10 months
JBossWS SVN: r3443 - in branches/jbossws-2.0/build/hudson/hudson-home/jobs: Release-Matrix-Step1 and 1 other directories.
by jbossws-commits@lists.jboss.org
Author: thomas.diesler(a)jboss.com
Date: 2007-06-05 05:51:16 -0400 (Tue, 05 Jun 2007)
New Revision: 3443
Modified:
branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-4.0/config.xml
branches/jbossws-2.0/build/hudson/hudson-home/jobs/Release-Matrix-Step1/config.xml
branches/jbossws-2.0/build/hudson/hudson-home/jobs/Release-Matrix-Step2/config.xml
Log:
Reschedule release matrix builds
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-4.0/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-4.0/config.xml 2007-06-05 09:35:04 UTC (rev 3442)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/AS-Tests-AS-4.0/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
@@ -30,7 +30,7 @@
# build/deploy jbossws-native
#
cd $JBWSDIR/integration/native
-ant $ENVIRONMENT -Djboss40.home=$JBOSS_INSTANCE-ejb3 main
+ant $ENVIRONMENT -Djboss40.home=$JBOSS_INSTANCE-ejb3 jars
ant $ENVIRONMENT -Djboss40.home=$JBOSS_INSTANCE deploy-jboss40
#
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/Release-Matrix-Step1/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/Release-Matrix-Step1/config.xml 2007-06-05 09:35:04 UTC (rev 3442)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/Release-Matrix-Step1/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
@@ -13,7 +13,7 @@
<enableRemoteTrigger>false</enableRemoteTrigger>
<triggers class="vector">
<hudson.triggers.TimerTrigger>
- <spec>0 2 * * *</spec>
+ <spec>0 5 * * *</spec>
</hudson.triggers.TimerTrigger>
</triggers>
<logRotator>
Modified: branches/jbossws-2.0/build/hudson/hudson-home/jobs/Release-Matrix-Step2/config.xml
===================================================================
--- branches/jbossws-2.0/build/hudson/hudson-home/jobs/Release-Matrix-Step2/config.xml 2007-06-05 09:35:04 UTC (rev 3442)
+++ branches/jbossws-2.0/build/hudson/hudson-home/jobs/Release-Matrix-Step2/config.xml 2007-06-05 09:51:16 UTC (rev 3443)
@@ -13,7 +13,7 @@
<enableRemoteTrigger>false</enableRemoteTrigger>
<triggers class="vector">
<hudson.triggers.TimerTrigger>
- <spec>0 3 * * *</spec>
+ <spec>0 6 * * *</spec>
</hudson.triggers.TimerTrigger>
</triggers>
<logRotator>
18 years, 10 months
JBossWS SVN: r3442 - branches/jbossws-2.0/jbossws-core/src/main/java/org/jboss/ws/extensions/xop/jaxws.
by jbossws-commits@lists.jboss.org
Author: heiko.braun(a)jboss.com
Date: 2007-06-05 05:35:04 -0400 (Tue, 05 Jun 2007)
New Revision: 3442
Modified:
branches/jbossws-2.0/jbossws-core/src/main/java/org/jboss/ws/extensions/xop/jaxws/ReflectiveAttachmentRefScanner.java
Log:
Scanner did return wrong results on mixed annotation styles
Modified: branches/jbossws-2.0/jbossws-core/src/main/java/org/jboss/ws/extensions/xop/jaxws/ReflectiveAttachmentRefScanner.java
===================================================================
--- branches/jbossws-2.0/jbossws-core/src/main/java/org/jboss/ws/extensions/xop/jaxws/ReflectiveAttachmentRefScanner.java 2007-06-05 09:29:59 UTC (rev 3441)
+++ branches/jbossws-2.0/jbossws-core/src/main/java/org/jboss/ws/extensions/xop/jaxws/ReflectiveAttachmentRefScanner.java 2007-06-05 09:35:04 UTC (rev 3442)
@@ -171,16 +171,17 @@
if(paramResult!=null)
{
- paramResult.setIndex(index);
- index++;
+ paramResult.setIndex(index);
results.add(paramResult);
}
- }
+ }
}
- }
+ index++;
+ }
+
return results;
}
18 years, 10 months
JBossWS SVN: r3441 - in trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref: jaxws and 1 other directory.
by jbossws-commits@lists.jboss.org
Author: heiko.braun(a)jboss.com
Date: 2007-06-05 05:29:59 -0400 (Tue, 05 Jun 2007)
New Revision: 3441
Modified:
trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/SWARefTestCase.java
trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/WrappedEndpoint.java
trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/WrappedEndpointImpl.java
trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/jaxws/ParameterAnnotation.java
Log:
Extend swaref tests to verifxy mixed annotation styles
Modified: trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/SWARefTestCase.java
===================================================================
--- trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/SWARefTestCase.java 2007-06-05 09:29:19 UTC (rev 3440)
+++ trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/SWARefTestCase.java 2007-06-05 09:29:59 UTC (rev 3441)
@@ -76,7 +76,7 @@
Service service = Service.create(new URL(wrappedEndpointURL+"?wsdl"), wrappedServiceQName);
WrappedEndpoint port = service.getPort(WrappedEndpoint.class);
- DataHandler response = port.parameterAnnotation(data, "Wrapped test");
+ DataHandler response = port.parameterAnnotation(new DocumentPayload(data), "Wrapped test", data);
assertNotNull("Response as null", response);
assertTrue("Contents are not equal", response.getContent().equals("Server data"));
}
Modified: trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/WrappedEndpoint.java
===================================================================
--- trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/WrappedEndpoint.java 2007-06-05 09:29:19 UTC (rev 3440)
+++ trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/WrappedEndpoint.java 2007-06-05 09:29:59 UTC (rev 3441)
@@ -37,6 +37,6 @@
@WebMethod
@XmlAttachmentRef
- DataHandler parameterAnnotation(@XmlAttachmentRef DataHandler data, String test) throws RemoteException;
+ DataHandler parameterAnnotation(DocumentPayload payload, String test, @XmlAttachmentRef DataHandler data) throws RemoteException;
}
Modified: trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/WrappedEndpointImpl.java
===================================================================
--- trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/WrappedEndpointImpl.java 2007-06-05 09:29:19 UTC (rev 3440)
+++ trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/WrappedEndpointImpl.java 2007-06-05 09:29:59 UTC (rev 3441)
@@ -79,7 +79,7 @@
@WebMethod
@XmlAttachmentRef
- public DataHandler parameterAnnotation(@XmlAttachmentRef DataHandler data, String test) throws RemoteException
+ public DataHandler parameterAnnotation(DocumentPayload payload, String test, @XmlAttachmentRef DataHandler data) throws RemoteException
{
try
{
Modified: trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/jaxws/ParameterAnnotation.java
===================================================================
--- trunk/jbossws-core/src/main/java/org/jboss/ws/metadata/umdm/ParameterMetaData.java 2007-06-05 09:28:40 UTC (rev 3439)
+++ trunk/jbossws-core/src/main/java/org/jboss/ws/metadata/umdm/ParameterMetaData.java 2007-06-05 09:29:19 UTC (rev 3440)
@@ -481,7 +481,9 @@
/**
* Identify MTOM and SWA:Ref parameter as these require special treatment.
- * This only affects JAX-WS endpoints
+ * This only affects JAX-WS endpoints.
+ *
+ * Note: For SEI parameter annotations this happens within the metadata builder.
* @param epType
*/
private void initializeAttachmentParameter(Type epType)
18 years, 10 months
JBossWS SVN: r3439 - trunk/jbossws-core/src/main/java/org/jboss/ws/extensions/xop/jaxws.
by jbossws-commits@lists.jboss.org
Author: heiko.braun(a)jboss.com
Date: 2007-06-05 05:28:40 -0400 (Tue, 05 Jun 2007)
New Revision: 3439
Modified:
trunk/jbossws-core/src/main/java/org/jboss/ws/extensions/xop/jaxws/ReflectiveAttachmentRefScanner.java
Log:
Scanner did create wrong results with mixed annotation styles
Modified: trunk/jbossws-core/src/main/java/org/jboss/ws/extensions/xop/jaxws/ReflectiveAttachmentRefScanner.java
===================================================================
--- trunk/jbossws-core/src/main/java/org/jboss/ws/extensions/xop/jaxws/ReflectiveAttachmentRefScanner.java 2007-06-05 09:27:51 UTC (rev 3438)
+++ trunk/jbossws-core/src/main/java/org/jboss/ws/extensions/xop/jaxws/ReflectiveAttachmentRefScanner.java 2007-06-05 09:28:40 UTC (rev 3439)
@@ -171,16 +171,16 @@
if(paramResult!=null)
{
- paramResult.setIndex(index);
- index++;
+ paramResult.setIndex(index);
results.add(paramResult);
-
}
- }
+ }
}
- }
+ index++;
+ }
+
return results;
}
18 years, 10 months
--- trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/jaxws/ParameterAnnotation.java 2007-06-05 09:29:19 UTC (rev 3440)
+++ trunk/testsuite/src/java/org/jboss/test/ws/jaxws/samples/swaref/jaxws/ParameterAnnotation.java 2007-06-05 09:29:59 UTC (rev 3441)
@@ -1,6 +1,8 @@
package org.jboss.test.ws.jaxws.samples.swaref.jaxws;
+import org.jboss.test.ws.jaxws.samples.swaref.DocumentPayload;
+
import javax.activation.DataHandler;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
@@ -12,51 +14,67 @@
@XmlRootElement(name = "parameterAnnotation", namespace = "http://swaref.samples.jaxws.ws.test.jboss.org/")
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "parameterAnnotation", namespace = "http://swaref.samples.jaxws.ws.test.jboss.org/", propOrder = {
- "arg0",
- "arg1"
-})
+ "arg0",
+ "arg1",
+ "arg2"
+ })
public class ParameterAnnotation {
- @XmlElement(name = "arg0", namespace = "")
- @XmlAttachmentRef
- private DataHandler arg0;
- @XmlElement(name = "arg1", namespace = "")
- private String arg1;
+ @XmlElement(name = "arg0", namespace = "")
+ private DocumentPayload arg0;
- /**
- *
- * @return
- * returns DataHandler
- */
- public DataHandler getArg0() {
- return this.arg0;
- }
+ @XmlElement(name = "arg1", namespace = "")
+ private String arg1;
- /**
- *
- * @param arg0
- * the value for the arg0 property
- */
- public void setArg0(DataHandler arg0) {
- this.arg0 = arg0;
- }
+ @XmlElement(name = "arg2", namespace = "")
+ @XmlAttachmentRef
+ private DataHandler arg2;
- /**
- *
- * @return
- * returns String
- */
- public String getArg1() {
- return this.arg1;
- }
- /**
- *
- * @param arg1
- * the value for the arg1 property
- */
- public void setArg1(String arg1) {
- this.arg1 = arg1;
- }
+ public DocumentPayload getArg0()
+ {
+ return arg0;
+ }
+ public void setArg0(DocumentPayload arg0)
+ {
+ this.arg0 = arg0;
+ }
+
+ /**
+ *
+ * @return
+ * returns DataHandler
+ */
+ public DataHandler getArg2() {
+ return this.arg2;
+ }
+
+ /**
+ *
+ * @param arg2
+ * the value for the arg0 property
+ */
+ public void setArg2(DataHandler arg2) {
+ this.arg2 = arg2;
+ }
+
+ /**
+ *
+ * @return
+ * returns String
+ */
+ public String getArg1() {
+ return this.arg1;
+ }
+
+ /**
+ *
+ * @param arg1
+ * the value for the arg1 property
+ */
+ public void setArg1(String arg1) {
+ this.arg1 = arg1;
+ }
+
}
18 years, 10 months
JBossWS SVN: r3440 - trunk/jbossws-core/src/main/java/org/jboss/ws/metadata/umdm.
by jbossws-commits@lists.jboss.org
Author: heiko.braun(a)jboss.com
Date: 2007-06-05 05:29:19 -0400 (Tue, 05 Jun 2007)
New Revision: 3440
Modified:
trunk/jbossws-core/src/main/java/org/jboss/ws/metadata/umdm/ParameterMetaData.java
Log:
Additional apidocs
Modified: trunk/jbossws-core/src/main/java/org/jboss/ws/metadata/umdm/ParameterMetaData.java
===================================================================